/// <reference types="react" />

import {Plugin as Plugin_2} from 'sanity'

/**
 * Document Branch Filter
 *
 * A pluggable Function for Filtering to a Top Concept Branch within a SKOS Concept Scheme
 * @param options.schemeId The unique six character concept identifier for the Concept Scheme to which you wish to filter.
 * @param options.branchId The unique six character concept identifier of a branch. Child concepts will be returned.
 * @returns A reference type filter for the child concepts of the designated branch in the selected Concept Scheme
 */
export declare function branchFilter(options: BranchOptions): BranchFilterResult

declare type BranchFilterResult = {
  filter: string
  params: BranchOptions
}

declare type BranchOptions = {
  schemeId: string
  branchId: string
}

declare interface Options {
  baseUri?: string
}

/**
 * Document Scheme Filter
 *
 * Pluggable Function for Filtering to a Single SKOS Concept Scheme
 * @param options.schemeId The unique six character concept identifier for the Concept Scheme to which you wish to filter.
 * @returns A reference type filter for Concepts and Top Concepts in the selected Concept Scheme
 */
export declare function schemeFilter(options: SchemeOptions): SchemeFilterResult

declare type SchemeFilterResult = {
  filter: string
  params: SchemeOptions
}

declare type SchemeOptions = {
  schemeId: string
}

/**
 * Defines a Sanity plugin for managing taxonomies.
 * @param options - Optional configuration options for the plugin.
 * @param options.baseUri - The base URI to use for SKOS concepts and concept schemes.
 * baseURI should follow an IANA http/s scheme and should terminate with either a / or #.
 * @returns A Sanity plugin object.
 */
export declare const taxonomyManager: Plugin_2<Options | undefined>

export declare const TreeView: ({document}: {document: any}) => JSX.Element

export {}
